@@ -1,25 +1,13 @@
-test_that("can override requests through mocking", {
+test_that("can override requests with local_ or with_", {
+  req <- request("https://google.com")
   resp <- response()
-  req <- request("https://google.com")
 
-  expect_equal(with_mocked_responses(~resp, req_perform(req)), resp)
-
-  local_mocked_responses(function(req) resp)
-  expect_equal(req_perform(req), resp)
-})
-
-test_that("can generate errors with mocking", {
-  local_mocked_responses(~ response(404))
-
-  req <- request("https://google.com")
-  expect_error(req_perform(req), class = "httr2_http_404")
-})
-
-test_that("local_mock and with_mock are deprecated", {
-  expect_snapshot(error = TRUE, {
-    local_mock(~ response(404))
-    . <- with_mock(NULL, ~ response(404))
+  with_mocked_responses(\(req) resp, {
+    expect_equal(req_perform(req), resp)
   })
+
+  local_mocked_responses(\(req) resp)
+  expect_equal(req_perform(req), resp)
 })
 
 test_that("mocked_response_sequence returns responses then errors", {
